@@ -2,8 +2,8 @@ from physiocurve.pressure import Pressure
 
 
 class PPG(Pressure):
-    def __init__(self, values, samplerate, index=None):
-        super().__init__(values, samplerate, index)
+    def __init__(self, values, samplerate):
+        super().__init__(values, samplerate)
 
     def sqi(self):
         raise NotImplementedError
